# PSYCH 4165 Lab 1
# command file for computing a repeated measures
# analysis of variance using lme() in R.
# Lewis O. Harvey, Jr.
# Department of Psychology
# University of Colorado

# load the nlme library to use lme()
library(nlme)

# plot three graphs in one panel
par(mfcol = c(3,1))

# Read data into R and store it in a data frame:
df <- read.delim("lab1_data.txt", header = TRUE)

# Calculate Weber's Constant (k) for each subject and
# compute the log of Weber's constant
# Add both to the data frame
df <- cbind(df, Weber_k = df$Dist_StandardDev / df$Standard)
df <- cbind(df, Log_k = log10(df$Weber_k))

# Specify standard weight as a factor instead
# of an integer (i.e., 100 or 200)
df$Standard <- factor(df$Standard)

# Write out a summary of the variables in the data frame:
summary(df)

# Make a histogram of the data
with(df, hist(Weber_k, breaks=10,
	xlab = "Weber's k",
	ylab = "Frequency",
	main = "Histogram of Lab 1 Weber's k"))
	
# Make a strip chart of the data
with(df, stripchart(Weber_k ~ Standard,
	method = "jitter", jitter = 0.03,
	xlab = "Weber's k", 
	ylab = "Standard Weight",
	main = "Strip Chart of Lab 1 Weber's k"))

# Make a box plot of the data:
boxplot(Weber_k ~ Standard, data = df,
	horizontal = TRUE,
	ylab = "Standard Weight",
	xlab = "Weber's k",
	main = "Box and Whisker Plot of Lab 1 Weber's k")

# compute the means
print(" ", quote = FALSE)
print("means", quote = FALSE)
print(with(df,tapply(Weber_k, Order, "mean")))
print(with(df,tapply(Weber_k, Standard, "mean")))

# use lme() to compute the ANOVA
print(" ", quote = FALSE)
print("Results of lme() Analysis Of Variance", quote = FALSE)

a <- lme(Weber_k ~ Standard * Order, data = df, random = ~ 1|Subj)
print(anova(a))

# return printing to one graph per panel
par(mfcol = c(1,1))